@@ -40,7 +40,6 @@ epoch = datetime(1970, 1, 1)
 logger = logging.getLogger("sentry_sdk.errors")
 
 MAX_STRING_LENGTH = 512
-MAX_FORMAT_PARAM_LENGTH = 128
 BASE64_ALPHABET = re.compile(r"^[a-zA-Z0-9/+=]*$")
 
 
@@ -162,7 +161,7 @@ class Dsn(object):
             return
         parts = urlparse.urlsplit(text_type(value))
 
-        if parts.scheme not in (u"http", u"https"):
+        if parts.scheme not in ("http", "https"):
             raise BadDsn("Unsupported scheme %r" % parts.scheme)
         self.scheme = parts.scheme
 
@@ -172,7 +171,7 @@ class Dsn(object):
         self.host = parts.hostname
 
         if parts.port is None:
-            self.port = self.scheme == "https" and 443 or 80
+            self.port = self.scheme == "https" and 443 or 80  # type: int
         else:
             self.port = parts.port
 
@@ -281,7 +280,7 @@ class Auth(object):
             rv.append(("sentry_client", self.client))
         if self.secret_key is not None:
             rv.append(("sentry_secret", self.secret_key))
-        return u"Sentry " + u", ".join("%s=%s" % (key, value) for key, value in rv)
+        return "Sentry " + ", ".join("%s=%s" % (key, value) for key, value in rv)
 
 
 class AnnotatedValue(object):
@@ -441,8 +440,7 @@ if PY2:
                 return rv
         except Exception:
             # If e.g. the call to `repr` already fails
-            return u"<broken repr>"
-
+            return "<broken repr>"
 
 else:
 
@@ -468,6 +466,9 @@ def filename_for_module(module, abs_path):
             return os.path.basename(abs_path)
 
         base_module_path = sys.modules[base_module].__file__
+        if not base_module_path:
+            return abs_path
+
         return abs_path.split(base_module_path.rsplit(os.sep, 2)[0], 1)[-1].lstrip(
             os.sep
         )
@@ -607,7 +608,6 @@ if HAS_CHAINED_EXCEPTIONS:
             exc_value = cause
             tb = getattr(cause, "__traceback__", None)
 
-
 else:
 
     def walk_exception_chain(exc_info):
@@ -773,7 +773,7 @@ def strip_string(value, max_length=None):
 
     if length > max_length:
         return AnnotatedValue(
-            value=value[: max_length - 3] + u"...",
+            value=value[: max_length - 3] + "...",
             metadata={
                 "len": length,
                 "rem": [["!limit", "x", max_length - 3, max_length]],
@@ -792,7 +792,9 @@ def _is_contextvars_broken():
         from gevent.monkey import is_object_patched  # type: ignore
 
         # Get the MAJOR and MINOR version numbers of Gevent
-        version_tuple = tuple([int(part) for part in gevent.__version__.split(".")[:2]])
+        version_tuple = tuple(
+            [int(part) for part in re.split(r"a|b|rc|\.", gevent.__version__)[:2]]
+        )
         if is_object_patched("threading", "local"):
             # Gevent 20.9.0 depends on Greenlet 0.4.17 which natively handles switching
             # context vars when greenlets are switched, so, Gevent 20.9.0+ is all fine.
